@@ -1,7 +1,7 @@
 mod app;
 
 use app::*;
-use leptos::*;
+use leptos::prelude::*;
 
 fn main() {
     console_error_panic_hook::set_once();
